/*
    \brief Deklarationen der Funktionen für den Zugriff auf enthaltene Listen und deren Veränderung.

    \author Bernd Ottmann
    \date   21.02.2003
*/
#pragma once
#ifndef DATAFOX_LISTS_H
#ifndef DOXYGEN_SHOULD_SKIP_THIS
#define DATAFOX_LISTS_H
#endif

#include "df_defines.h"

#ifndef DOXYGEN_SHOULD_SKIP_THIS
#if (DF_API_VERSION >= 0x04010100)
//    \export{_DFCOpenTable@28, DFCOpenTable}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCOpenTable( int connectionId, int deviceAddress, const char *name, int options, int *tableHandle, const char *reserved, int *errorNumber );

//    \export{_DFCCloseTable@16, DFCCloseTable}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCCloseTable( int connectionId, int deviceAddress, int tableHandle, int *errorNumber );

//    \export{_DFCSetFilter@20, DFCSetFilter}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCSetFilter( int connectionId, int deviceAddress, int tableHandle, const char *value, int *errorNumber );

//    \export{_DFCGetFilter@24, DFCGetFilter}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCGetFilter( int connectionId, int deviceAddress, int tableHandle, char *value, int *valueLength, int *errorNumber );

//    \export{_DFCClearFilter@16, DFCClearFilter}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCClearFilter( int connectionId, int deviceAddress, int tableHandle, int *errorNumber );

//    \export{_DFCSetField@24, DFCSetField}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCSetField( int connectionId, int deviceAddress, int tableHandle, const char *name, const char *value, int *errorNumber );

//    \export{_DFCGetField@28, DFCGetField}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCGetField( int connectionId, int deviceAddress, int tableHandle, const char *name, char *value, int *valueLength, int *errorNumber );

//    \export{_DFCSkip@24, DFCSkip}
DF_API_EXTERN_DECORATE int DF_API_CALL DFCSkip( int connectionId, int deviceAddress, int tableHandle, int offset, int origin, int *errorNumber );

#endif
#endif

#if (DF_API_VERSION >= 0x04030800)

/*!
    \brief Öffnet eine vorhandene Tabelle (Liste) zur Bearbeitung.

    Öffnet eine Tabelle und macht diese über einen Handle zugreifbar.

    \ingroup lists

    \export{DFCTableOpen, DFCTableOpen}

    \note Die Bezeichnung Tabelle wurde gewählt, da zukünftig ggf. auch Datensatztabellen über diese Funktionen
    Bearbeitet werden sollen. Allgemein beziehen sich die Funktionen aktuell jedoch auf Listen.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] name Tabellenname. Die Tabellen sind in verschiedene Bereiche eingeteilt, welche Sie über einen Namenspräfix ansprechen.
    <table class="paramvalues">
        <tr><th>Präfix</th><th>Bedeutung</th></tr>
        <tr><td>LIST.</td><td>Listen des Setups. Beispiel: LIST.Personalstamm </td></tr>
        <tr><td>ACCESS.</td><td>Listen der Zutrittskontrolle. Beispiel: ACCESS.Reader </td></tr>
    </table>
    \param[in] options Reservierter Parameter. Standardwert 0.
    \param[out] tableHandle Variable für den Tabellenhandle. Dieser wird bei den weiteren Funktionsaufrufen zur
    Bearbeitung als Parameterwert benötigt.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableOpen(int connectionId, int deviceAddress, const char *name, int options, int *tableHandle);

/*!
    \brief Schließt eine geöffnete Tabelle.

    Schließt eine zuvor mit DFCTableOpen() geöffnete Tabelle.

    \ingroup lists

    \export{DFCTableClose, DFCTableClose}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableClose(int connectionId, int deviceAddress, int tableHandle);

/*!
    \brief Setzen eines Datenfilters auf die Tabelle.

    Setzt ein Filterkriterium auf Spalten der Tabelle.

    \ingroup lists

    \export{DFCTableSetFilter, DFCTableSetFilter}

    \warning Firmwareversionen kleiner 04.03.08 unterstüzen eine Filterung auf eine Spalte. Sie führen das Setzen von
    Filterangaben für mehr als eine Spalte fehlerfrei, interpretieren jedoch nur die erste Filterspalte.

    \note Nach Ausführung dieser Funktion sitzt der Satzzeiger auf der
    ersten passenden Datenzeile. Mit DFCTableSetCurrentRow() kann der Satzzeiger in den gefilterten Datenzeilen
    bewegt werden.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] value Zeichenfolge des Filters.\n
    Die Filterangabe wird durch <em>Spaltenname='Spaltenwert'</em> durchgeführt.\n
    Ab der Firmwareversion 04.03.08.01 kann zusätzlich eine 2 Spalte angegeben werden:
    <em>Spaltenname='Spaltenwert';Spaltenname2='Spaltenwert'</em>

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableSetFilter(int connectionId, int deviceAddress, int tableHandle, const char *value);

/*!
    \brief Lesen des Datenfilters der Tabelle.

    Wurde ein Datenfilter auf die Tabelle gesetzt wird dieser durch Aufruf gelesen.

    \ingroup lists

    \export{DFCTableGetFilter, DFCTableGetFilter}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] value Zeichenarray für den Filterwert.
    \param[in] valueSize Als \c in die Länge des Zeichenarrays von \a value, als \c out die übergebene Anzahl Zeichen.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableGetFilter(int connectionId, int deviceAddress, int tableHandle, char *value, int *valueSize);

/*!
    \brief Entfernen eines gesetzten Datenfilters von der Tabelle.

    Wurde mit DFCTableSetFilter() ein Filter auf die Tabelle gesetzt, kann dieser durch Aufruf entfernt werden.

    \ingroup lists

    \export{DFCTableRemoveFilter, DFCTableRemoveFilter}

    \note Nach Ausführung dieser Funktion sitzt der Satzzeiger auf der
    ersten Datenzeile der Tabelle. Mit DFCTableSetCurrentRow() kann der Satzzeiger bewegt werden.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableRemoveFilter(int connectionId, int deviceAddress, int tableHandle);

/*!
    \brief Ermittlung der aktuellen Datensatzanzahl.

    Es wird zwischen Gesamtanzahl, unsortiert angefügter und als gelöscht markierter Datenzeilen unterschieden.

    \ingroup lists

    \export{DFCTableGetRowCount, DFCTableGetRowCount}

    \note Wenn die Anzahl für \a unsortedCount oder auch \a deletedCount eine gewisse Größe erreichen, sollten Sie
    die komplette Liste neu übertragen. Da durch zu viele unsortierte Datenzeilen eine Datensuche verlangsamt wird
    und die als gelöscht markierte Datenzeilen unnötigen Speicher benötigen.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[out] currentCount Gesamtanzahl ungelöschter Datenzeilen.
    \param[out] unsortedCount Anzahl unsortiert angefügter Datenzeilen.
    \param[out] deletedCount Anzahl als gelöscht markierter Datenzeilen.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableGetRowCount(int connectionId, int deviceAddress, int tableHandle, int *currentCount, int *unsortedCount, int *deletedCount);

/*!
    \brief Ermittelt die aktuelle Zeilennummer.

    Ermittelt die Zeilennummer auf der aktuell der Satzzeiger steht.

    \ingroup lists

    \export{DFCTableGetCurrentRow, DFCTableGetCurrentRow}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[out] currentRow Aktuelle Zeilennummer.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableGetCurrentRow(int connectionId, int deviceAddress, int tableHandle, int *currentRow);

/*!
    \brief Setzen der aktuellen Zeilennummer.

    Setzt den Satzzeiger auf die angegebene Zeilennummer.

    \ingroup lists

    \export{DFCTableSetCurrentRow, DFCTableSetCurrentRow}

    \note Bei einer gefilterten Liste beziehen sich die Angaben auf die dem Filterkriteren entsprechenden Datenzeilen.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] offset Anzahl zu übergehender Datenzeilen.
    \param[in] direction Worauf sich \c offset beziehen soll.
    <table class="paramvalues">
        <tr><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>0</td><td>vom Beginn der Tabelle</td></tr>
        <tr><td>1</td><td>von aktueller Position</td></tr>
        <tr><td>2</td><td>vom Ende</td></tr>
    </table>

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableSetCurrentRow(int connectionId, int deviceAddress, int tableHandle, int offset, int direction);

/*!
    \brief Überschreibt die aktuelle Datenzeile mit den angegeben Daten.

    Die Datenzeile auf welcher der aktuelle Satzzeiger steht wird mit den angegebenen Daten überschrieben.

    \ingroup lists

    \export{DFCTableSetCurrentRowData, DFCTableSetCurrentRowData}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Nach der Ausführung wird auf die nächste Datenzeile gewechselt.
        Dieses erspart ein folgender Aufruf von DFCTableSetCurrentRow().</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] separator Angabe der in \c data enthaltenen Datenfelder.
    <table class="paramvalues">
        <tr><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>0</td><td>Die Feldwerte sind als Zeichenarray im Binärformat angegeben.</td></tr>
        <tr><td>9</td><td>Sie sind durch einen Tabulator '\\t' voneinander getrennt.</td></tr>
        <tr><td>59</td><td>Sie sind durch ein Semikolon ';' voneinander getrennt.</td></tr>
    </table>
    \param[in] data Datenarray.
    \param[in] dataSize Länge des Datenarrays.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableSetCurrentRowData(int connectionId, int deviceAddress, int tableHandle, int flags, char separator, 
                                                        const char *data, int dataSize);

/*!
    \brief Überschreiben eines Feldwertes.

    Überschreibt in der aktuellen Datenzeile den angegebenen Feldwert.

    \ingroup lists

    \export{DFCTableSetCurrentColumnData, DFCTableSetCurrentColumnData}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Nach der Ausführung wird auf die nächste Datenzeile gewechselt.
        Dieses erspart ein folgender Aufruf von DFCTableSetCurrentRow().</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] name Feldname.
    \param[in] data Feldwert.
    \param[in] dataSize Länge des Feldwertes.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableSetCurrentColumnData(int connectionId, int deviceAddress, int tableHandle, int flags, const char *name, 
                                                           const char *data, int dataSize);

/*!
    \brief Ließt die aktuelle Datenzeile.

    Die aktuelle Datenzeile wird in gelesen.

    \ingroup lists

    \export{DFCTableGetCurrentRowData, DFCTableGetCurrentRowData}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Nach der Ausführung wird auf die nächste Datenzeile gewechselt.
        Dieses erspart ein folgender Aufruf von DFCTableSetCurrentRow().</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] separator Angabe der in \c data enthaltenen Datenfelder.
    <table class="paramvalues">
        <tr><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>0</td><td>Die Feldwerte sind als Zeichenarray im Binärformat angegeben.</td></tr>
        <tr><td>9</td><td>Sie sind durch einen Tabulator '\\t' voneinander getrennt.</td></tr>
        <tr><td>59</td><td>Sie sind durch ein Semikolon ';' voneinander getrennt.</td></tr>
    </table>
    \param[in] data Datenarray.
    \param[in,out] dataSize Als \c in die Länge des Datenarrays von \a data, als \c out die Anzahl übergebener Daten.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableGetCurrentRowData(int connectionId, int deviceAddress, int tableHandle, int flags, char separator,
                                                        char *data, int *dataSize);

/*!
    \brief Lesen eines Feldwertes.

    Ließt aus der aktuellen Datenzeile den angegebenen Feldwert.

    \ingroup lists

    \export{DFCTableGetCurrentColumnData, DFCTableGetCurrentColumnData}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Nach der Ausführung wird auf die nächste Datenzeile gewechselt.
        Dieses erspart ein folgender Aufruf von DFCTableSetCurrentRow().</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] name Feldname.
    \param[in] data Datenarray.
    \param[in,out] dataSize Als \c in die Länge des Datenarrays von \a data, als \c out die Anzahl übergebener Daten.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableGetCurrentColumnData(int connectionId, int deviceAddress, int tableHandle, int flags, const char *name, 
                                                           char *data, int *dataSize);

/*!
    \brief Überschreiben einer Zeilenspalte der gesamten dem aktuellen Filterkriterium entsprechenden Datenzeilen.

    Allen, dem aktuell entpsrechenden Filterkriterium entsprechenden Datenzeilen, wird der angegebene Spaltenwert zugewiesen.

    \ingroup lists

    \export{DFCTableSetAllRowsToColumnData, DFCTableSetAllRowsToColumnData}

    \note Über diese Funktion kann Beispielsweise ein Anwesenheitsstatus aller Mitarbeiter mit einem Aufruf auf einen
    definierten Zustand eingestellt werden.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] name Feldname.
    \param[in] data Feldwert.
    \param[in] dataSize Länge des Feldwertes.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableSetAllRowsToColumnData(int connectionId, int deviceAddress, int tableHandle, int flags, const char *name, 
                                                           const char *data, int dataSize);

/*!
    \brief Anfügen einer neuen Datenzeile.

    Der Tabelle wird die angegebene Datenzeile angefügt.

    \ingroup lists

    \export{DFCTableAppendRowData, DFCTableAppendRowData}

    \note \li Handelt es sich bei der Tabelle um eine Liste mit Sortiertspalte, wird die Datenzeile als unsortierte
    Datenzeile angefügt. Bei zu vielen unsortierten Datenzeilen wird die Datensuche verlangsamt, deswegen
    sollten Tabellen mit zu vielen unsortierten Datenzeilen komplett übertragen werden. Mit DFCTableGetRowCount()
    kann unter anderen auch die Anzahl unsortiert hinzugefügter Datenzeilen ermittelt werden.
    \li Die durch diese Funktion angefügten Datenzeilen werden bei einer Auswahl über die Setup-Feldfunktion
    "Aus Liste auswählen" unsortiert angezeigt und sind somit die zuletzt angezeigten Datenzeilen.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>
    \param[in] separator Angabe der in \c data enthaltenen Datenfelder.
    <table class="paramvalues">
        <tr><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>0</td><td>Die Feldwerte sind als Zeichenarray im Binärformat angegeben.</td></tr>
        <tr><td>9</td><td>Sie sind durch einen Tabulator '\\t' voneinander getrennt.</td></tr>
        <tr><td>59</td><td>Sie sind durch ein Semikolon ';' voneinander getrennt.</td></tr>
    </table>
    \param[in] data Datenarray.
    \param[in] dataSize Länge des Datenarrays.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableAppendRowData(int connectionId, int deviceAddress, int tableHandle, int flags, char separator, 
                                                        const char *data, int dataSize);

/*!
    \brief Aktuelle Datenzeile als gelöscht markieren.

    Die aktuelle Datenzeile wird als gelöscht markiert und ein weiterer Zugriff ist nicht möglich.

    \ingroup lists

    \export{DFCTableDeleteCurrentRow, DFCTableDeleteCurrentRow}

    \note Bei zu vielen als gelöscht markierten Datenzeilen wird unnötig Speicher belegt, deswegen
    sollten Tabellen mit zu vielen gelöschten Datenzeilen komplett übertragen werden. Mit DFCTableGetRowCount()
    kann unter anderen auch die Anzahl gelöschter Datenzeilen ermittelt werden.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Nach der Ausführung wird auf die nächste Datenzeile gewechselt.
            Dieses erspart ein folgender Aufruf von DFCTableSetCurrentRow().</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableDeleteCurrentRow(int connectionId, int deviceAddress, int tableHandle, int flags);

/*!
    \brief Markiert alle dem Filterkriterium enstsprechenden Datenzeilen als gelöscht.

    Durch einen folgenden Aufruf von DFCTableRemoveFilter() muss ein ggf. gesetzter Filter gelöscht werden.
    Wurde die Liste mit dem Flag für "Gesamte Liste" gelöscht, dann steht die Liste als Leere Liste zur Verfügung
    und kann mittels DFCTableAppendRowData() gefüllt werden. Sie muss mit DFCTableClose() geschlossen werden.

    \ingroup lists

    \export{DFCTableDeleteAvailableRows, DFCTableDeleteAvailableRows}

    \note Bei zu vielen als gelöscht markierten Datenzeilen wird unnötig Speicher belegt, deswegen
    sollten Tabellen mit zu vielen gelöschten Datenzeilen komplett übertragen werden. Mit DFCTableGetRowCount()
    kann unter anderen auch die Anzahl gelöschter Datenzeilen ermittelt werden.

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] tableHandle Tabellenhandle.
    \param[in] flags Gibt zusätzliche Funktionalitäten an.
    <table class="paramvalues">
        <tr><th>Bitnummer</th><th>Wert</th><th>Bedeutung</th></tr>
        <tr><td>1</td><td>1</td><td>Alle Listenzeilen löschen. Ansonsten werden nur dem Filterkriterium entsprechende Datenzeilen gelöscht.</td></tr>
        <tr><td>...</td><td></td><td>Nicht verwendet. Bitte immer 0 übergeben.</td></tr>
    </table>

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.03.08 enthalten
*/
DF_API_EXTERN int DF_API_CALL DFCTableDeleteAvailableRows(int connectionId, int deviceAddress, int tableHandle, int flags);

#endif

#endif
