#pragma once
#ifndef DEVICE_INFO_H
#define DEVICE_INFO_H

#include "hardware_info.h"
#include "software_info.h"
#include "firmware_options.h"

class DeviceInfo
{
public:
    DeviceInfo();
    virtual ~DeviceInfo();

public:
    void clear();

    void setVersionBootloader( const std::string &version );
    std::string versionBootloader() const;

    void setBootloaderMode( bool active );
    bool bootloaderMode() const;

    void setHardwareInfo( const HardwareInfo &hardwareInfo );
    HardwareInfo &hardwareInfo();
    
    void setFileHardwareInfo( const FileHardwareInfo &file );
    FileHardwareInfo &fileHardwareInfo();
    listItemBoard collectModuleIds( const setModuleId &ids );

    void setVersionFirmware( const std::string &version );
    std::string versionFirmware() const;

    void setSoftwareInfo( const SoftwareInfo &softwareInfo );
    SoftwareInfo &softwareInfo();

    void setFirmwareOptions( const FirmwareOptions &firmwareOptions );
    FirmwareOptions &firmwareOptions();

    void setSerialNumber( unsigned int serial );
    unsigned int serialNumber() const;

    void setPasswordKey( const std::string &key );
    std::string passwordKey() const;

    void setVersionFingerprint( const std::string &version );
    std::string versionFingerprint() const;

    void setVersionUSBHost( const std::string &version );
    std::string versionUSBHost() const;

    void setVersionGPS( const std::string &version );
    std::string versionGPS() const;

    void setVersionTCPIP( const std::string &version );
    std::string versionTCPIP() const;

    void setMacAddress( const std::string &address );
    std::string macAddress() const;

    void setAccessControlMasterId( const std::string &id );
    std::string accessControlMasterId() const;

    void setTimeboyGroupId( const std::string &id );
    std::string timeboyGroupId() const;

    void setBoardApplication( const std::string &val );
    std::string boardApplication() const;

    void setBoardPlace_0_Output_1_Mode( const std::string &mode );
    std::string boardPlace_0_Output_1_Mode() const;

    void setBoardPlace_0_Serial_1_Use( const std::string &use );
    std::string boardPlace_0_Serial_1_Use() const;

    void setBoardPlace_0_Serial_2_Use( const std::string &use );
    std::string boardPlace_0_Serial_2_Use() const;

    void setTimeStartOS( const std::string &val );
    std::string timeStartOS() const;

    void setOffTimeLong( const std::string &val );
    std::string offTimeLong() const;

    void setOffTimeShort( const std::string &val );
    std::string offTimeShort() const;

    void setOnTime( const std::string &val );
    std::string onTime() const;

public: // Helper / Shorties
    bool importStructHardwareInfo( const StructHardwareInfo &info );
    StructHardwareInfo structHardwareInfo();

    void setStructSoftwareInfo( const StructSoftwareInfo &info );
    StructSoftwareInfo structSoftwareInfo() const;

    StructSoftwareInfo checkInfo( const StructSoftwareInfo &info );
    int SoftwareInfoToString( const StructSoftwareInfo &swInfo, std::string &info );

    int compareInfos( const StructHardwareInfo &hwInfo, const StructSoftwareInfo &swInfo );

public: // Shorties für FirmwareOptions
    void setSystemFlags( unsigned int flags );
    unsigned int systemFlags() const;

    void setTypeExternalReader( unsigned char type );
    unsigned char getTypeExternalReader();

    void setOptionIOModule( unsigned char enabled );
    unsigned char getOptionIOModule();

    void setOptionTBAdaption( unsigned char enabled );
    unsigned char getOptionTBAdaption();

    void setOptionComServer( unsigned char enabled );
    unsigned char getOptionComServer();

    void setOptionTPWrite( unsigned char enabled );
    unsigned char getOptionTPWrite();

    void setOptionHTTP( unsigned char enabled );
    unsigned char getOptionHTTP();

    void setOptionLanguage( unsigned char enabled );
    unsigned char getOptionLanguage();

    void setOptionBiokeyUpdate( unsigned char enabled );
    unsigned char getOptionBiokeyUpdate();

    void setSetupOptions( unsigned short mask, unsigned short options );
    unsigned short getSetupOptions( unsigned short mask );

    void setPayableOptions( unsigned char mask, unsigned char options );
    bool isPayableOption( FirmwareOptions::EnumPayableOption option );

public: // Fehlerbehandlung
    std::string m_errorText;

private: // Variablen
    std::string _versionBootloader;
    bool _bootloaderMode;
    std::string _versionFirmware;

    unsigned int _serialNumber;

    HardwareInfo _hardwareInfo;

    std::string _versionFingerprint;
    std::string _versionUSBHost;
    std::string _versionGPS;
    std::string _versionTCPIP;

    std::string _macAddress;

    SoftwareInfo _softwareInfo;
    std::string _passwordKey;

    FirmwareOptions _firmwareOptions;

    std::string _accessControlMasterId;
    std::string _timeboyGroupId;

    std::string _boardApplication;
    std::string _boardPlace_0_Output_1_Mode;
    std::string _boardPlace_0_Serial_1_Use;
    std::string _boardPlace_0_Serial_2_Use;

    std::string _timeStartOS;
    std::string _offTimeLong;
    std::string _offTimeShort;
    std::string _onTime;

};

#endif
