#pragma once
#ifndef WLAN_CONFIG_STRUCTS_H
#define WLAN_CONFIG_STRUCTS_H

#pragma pack(push, 1)

struct WLANCONFIGNODE
{
  unsigned char version;                 ///< Versionsnummer der Konfigurationsstrukturen
  unsigned char cnt;                     ///< Anzahl der folgenden Konfigurationsstrukturen.
  unsigned char crypt;                   ///< Verschluesselungsmethode:
                                         ///< 0 -> Unverschluesselt
                                         ///< 1 -> Verschluesselt mit RC4 und Datafox-Key
  unsigned char defaultConfig;           ///< Index der zu verwendenden Standardkonfiguration.
  unsigned char flags;                   ///< Flag-Feld fuer Konfigurationsuebergreifende Optionen.
                                         ///< Bit0: Automatische Wahl der anzuwendenden Konfiguration.
  unsigned char temp[7];                 ///< Reserve
  unsigned int ptrWlanConfigArray;       ///< Offset auf das folgende Pointerarray der Offsets auf die einzelnen Folgestrukturen vom Typ WLANCONFIG.
};// 16 Byte

// Struktur der WLAN Einstellungen, auch Matchport
struct WLANCONFIG
{
           char SSID[33];                 ///< SSID der WLAN Verbindung
  unsigned char EnableWLAN;               ///< WLAN->1 oder LAN->0 aktiv (Matchport)  
  unsigned char Type;                     ///< AdHoc->1, Infrastructure->0
  unsigned char Band;                     ///< 0->2.4GHz, 1->5GHz (nur RS9110)
  unsigned char Channel;                  ///< Funkkanal Matchport 1..13, RS9110 0-all Cannels, 1..13 2,4GHz, 1..24 5GHz
  unsigned char Country;                  ///< Länderkennung (Country Code) (Matchport)
  unsigned char Security;                 ///< Sicherheitstyp 0-None, 1-WEP, 2-WPA, 3-WPA2
  unsigned char Authentication;           ///< Echtheitsprüfung, 0->None, 1-> mit Key, Shared Key/Pre Shared Key, bei WPA und WPA2 immer auf 1 setzen !!!
  unsigned char PairwiseEncryptionMethod; ///> Verschlüsselung(Matchport+RS9110) 0-None, 1-WEP 64Bit, 2-WEP 128Bit, 3-TKIP, 4-AES(CCMP)
  unsigned char GroupEncryptionMethod;    ///> Verschlüsselung(nur Matchport bei WPA und WPA2) 0-No Group Encr., 1-WEP 64/128, 3-TKIP, 4-AES
           char Key[64];                  ///< ACHTUNG:Fehlende Nullterminierung! 
                                          ///< Verschlüsselungskey Hexstring bei WPA max 64Zeichen ohne Nullterminierung, 
                                          ///< Hexstring bei WEP64 10 Zeichen, Hexstring bei WEP128 26 Zeichen, 
                                          ///< bei Passphrase WPA max 31Zeichen, Hex bei WEP64 5 Zeichen, Hex bei WEP128 13 
  unsigned char KeyType;                  ///< Schlüsseltyp 0 = Hexstring, 1 = Passphrase
  unsigned char TxKeyIndex;               ///< nur Matchport, Nr. des WEP Keys der benutzt werden soll 0..3 entspricht TXKey1..TXKey4
  unsigned char Autofallback;             ///< Automatische Suche der besten Übertragungsrate (Matchport) 0 Fix, 1 Auto Data Rate
  unsigned char TxDataRate;               ///< Datenübertragungsrate Matchport 0..7, RS9110 1-12 und 0 Auto
  unsigned char RadioPower;               ///< Stromsparen erlaubt?
  unsigned char PowerLevel;               ///< Sendeleistung Matchport 0..3, RS9110 0..2
  unsigned char DHCP;                     ///< 0-disablel, 1-enable AutoIP über DHCP
           char IpAddress[16];            ///< zugewiesene Adresse des Moduls
  unsigned short Port;                    ///< 0..65535
           char Hostbits[4];              ///< 0..24 Sub-Netmask: 255.255.255.252 = 2 / 255.255.255.248 = 3 /255.255.255.0 = 8 siehe Doku Lantronix
           char SubNetWorkMask[16];       ///< Sub-Netmask
           char GateWay[16];              ///< Gateway für anderes Netzwerk
  unsigned char RemoteAccess;             ///< nur Matchport, Fernzugriff über Telnet usw.
  unsigned char Alive;                    ///< Zyklus in dem die Verbindung geprüft wird (nur Matchport)
           char Name[33];                 ///< Bezeichnung fuer diese WLAN-Konfiguration (Anzeige im Geraetebios)
  unsigned short timeout;                 ///< Auszeit zwischen den Versuchen ein bekanntes Netz zu finden in Sekunden, Bereich 30 - 65000. Default 60.
  unsigned char flags;                    ///< Flags fuer die gesamte Konfiguration.
                                          ///< Bit1: Gesetzt bedeutet, SSID und Key werden mit RC4 und Datafoxkey verschluesselt geliefert.
                                          ///< Bit2-8: Unused
  unsigned char startupTimeout;           ///< Bei LAN die Wartezeit beim Hochfahren bis aufgrund einer Fehleneden ARP-Antwort ein Reset durchgeführt wird.
  unsigned char temp[12];                 ///< Reserve
  unsigned short crc;                     ///< Pruefsumme um die gueltige Entschluesselung sicherzustellen.

};// 220

#pragma pack(pop)

#endif
